(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core')) :
    typeof define === 'function' && define.amd ? define('angular-value-flash', ['exports', '@angular/core'], factory) :
    (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global['angular-value-flash'] = {}, global.ng.core));
}(this, (function (exports, core) { 'use strict';

    var numberFormatter = function (value) { return Intl.NumberFormat('en').format(value); };
    var ɵ0 = numberFormatter;
    var currencyFormatter = function (value) { return Intl.NumberFormat('en', { style: 'currency', currency: 'USD' }).format(value); };
    var ɵ1 = currencyFormatter;
    var percentageFormatter = function (value) { return Intl.NumberFormat('en', {
        style: 'percent',
        // See: https://github.com/microsoft/TypeScript/issues/36533
        // @ts-ignore
        signDisplay: 'exceptZero',
    }).format(value); };
    var ɵ2 = percentageFormatter;
    var defaultFormatter = function (value) { return "" + value; };
    var ɵ3 = defaultFormatter;
    var formatters = {
        default: defaultFormatter,
        // eslint-disable-next-line id-blacklist
        number: numberFormatter,
        currency: currencyFormatter,
        percentage: percentageFormatter,
    };

    var ValueFlashComponent = /** @class */ (function () {
        // #endregion Properties (11)
        // #region Constructors (1)
        function ValueFlashComponent() {
            // #region Properties (11)
            /**
             * Color value when the component flashes 'down'.
             */
            this.downColor = 'red';
            /**
             * One of the built in formatters.
             */
            this.formatter = 'default';
            /**
             * Prefix for the CSS selectors in the DOM.
             */
            this.stylePrefix = 'rvf_Flash';
            /**
             * Amount of time the flashed state is visible for, in milliseconds.
             */
            this.timeout = 200;
            /**
             * Transition length, in milliseconds.
             */
            this.transitionLength = 100;
            /**
             * Color value when the component flashes 'up'.
             */
            this.upColor = 'green';
            /**
             * Value to display. The only required prop.
             */
            this.value = 0;
        }
        Object.defineProperty(ValueFlashComponent.prototype, "formattedValue", {
            // #endregion Constructors (1)
            // #region Public Accessors (2)
            get: function () {
                return this.usedFormatter(this.value);
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(ValueFlashComponent.prototype, "usedFormatter", {
            get: function () {
                var _a;
                return (_a = this.formatterFn) !== null && _a !== void 0 ? _a : formatters[this.formatter];
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(ValueFlashComponent.prototype, "valueHolder", {
            // #endregion Public Accessors (2)
            // #region Private Accessors (1)
            get: function () {
                return this.valueHolderRef.nativeElement;
            },
            enumerable: false,
            configurable: true
        });
        // #endregion Private Accessors (1)
        // #region Public Methods (3)
        ValueFlashComponent.prototype.handleValueChange = function (valueChange) {
            var _this = this;
            this.valueHolder.style.transition = '';
            if (valueChange.currentValue > valueChange.previousValue) {
                this.valueHolder.classList.add(this.stylePrefix + "--flashing-up");
                this.valueHolder.style.backgroundColor = this.upColor;
            }
            else if (valueChange.currentValue < valueChange.previousValue) {
                this.valueHolder.classList.add(this.stylePrefix + "--flashing-down");
                this.valueHolder.style.backgroundColor = this.downColor;
            }
            clearTimeout(this.animationTimeout);
            this.animationTimeout = setTimeout(function () { return _this.clearFlashingState(); }, this.timeout);
        };
        ValueFlashComponent.prototype.ngOnChanges = function (changes) {
            if (changes.value && changes.value.previousValue !== undefined) {
                this.handleValueChange(changes.value);
            }
        };
        // #endregion Public Methods (3)
        // #region Private Methods (1)
        ValueFlashComponent.prototype.clearFlashingState = function () {
            var _a;
            this.valueHolder.style.transition = (_a = this.transition) !== null && _a !== void 0 ? _a : "background-color " + this.transitionLength + "ms ease-in-out";
            this.valueHolder.classList.remove(this.stylePrefix + "--flashing-down");
            this.valueHolder.classList.remove(this.stylePrefix + "--flashing-up");
            this.valueHolder.style.backgroundColor = '';
        };
        return ValueFlashComponent;
    }());
    ValueFlashComponent.decorators = [
        { type: core.Component, args: [{
                    selector: 'value-flash',
                    template: "<div #valueHolder>{{ formattedValue }}</div>\r\n",
                    changeDetection: core.ChangeDetectionStrategy.OnPush
                },] }
    ];
    ValueFlashComponent.ctorParameters = function () { return []; };
    ValueFlashComponent.propDecorators = {
        downColor: [{ type: core.Input }],
        formatter: [{ type: core.Input }],
        formatterFn: [{ type: core.Input }],
        stylePrefix: [{ type: core.Input }],
        timeout: [{ type: core.Input }],
        transition: [{ type: core.Input }],
        transitionLength: [{ type: core.Input }],
        upColor: [{ type: core.Input }],
        value: [{ type: core.Input }],
        valueHolderRef: [{ type: core.ViewChild, args: ['valueHolder',] }]
    };

    var ValueFlashModule = /** @class */ (function () {
        function ValueFlashModule() {
        }
        return ValueFlashModule;
    }());
    ValueFlashModule.decorators = [
        { type: core.NgModule, args: [{
                    declarations: [ValueFlashComponent],
                    imports: [],
                    exports: [ValueFlashComponent],
                },] }
    ];

    /*
     * Public API Surface of value-flash
     */

    /**
     * Generated bundle index. Do not edit.
     */

    exports.ValueFlashComponent = ValueFlashComponent;
    exports.ValueFlashModule = ValueFlashModule;

    Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=angular-value-flash.umd.js.map
