import { Component, ChangeDetectionStrategy, Input, ViewChild, NgModule } from '@angular/core';

const numberFormatter = (value) => Intl.NumberFormat('en').format(value);
const ɵ0 = numberFormatter;
const currencyFormatter = (value) => Intl.NumberFormat('en', { style: 'currency', currency: 'USD' }).format(value);
const ɵ1 = currencyFormatter;
const percentageFormatter = (value) => Intl.NumberFormat('en', {
    style: 'percent',
    // See: https://github.com/microsoft/TypeScript/issues/36533
    // @ts-ignore
    signDisplay: 'exceptZero',
}).format(value);
const ɵ2 = percentageFormatter;
const defaultFormatter = (value) => `${value}`;
const ɵ3 = defaultFormatter;
const formatters = {
    default: defaultFormatter,
    // eslint-disable-next-line id-blacklist
    number: numberFormatter,
    currency: currencyFormatter,
    percentage: percentageFormatter,
};

class ValueFlashComponent {
    // #endregion Properties (11)
    // #region Constructors (1)
    constructor() {
        // #region Properties (11)
        /**
         * Color value when the component flashes 'down'.
         */
        this.downColor = 'red';
        /**
         * One of the built in formatters.
         */
        this.formatter = 'default';
        /**
         * Prefix for the CSS selectors in the DOM.
         */
        this.stylePrefix = 'rvf_Flash';
        /**
         * Amount of time the flashed state is visible for, in milliseconds.
         */
        this.timeout = 200;
        /**
         * Transition length, in milliseconds.
         */
        this.transitionLength = 100;
        /**
         * Color value when the component flashes 'up'.
         */
        this.upColor = 'green';
        /**
         * Value to display. The only required prop.
         */
        this.value = 0;
    }
    // #endregion Constructors (1)
    // #region Public Accessors (2)
    get formattedValue() {
        return this.usedFormatter(this.value);
    }
    get usedFormatter() {
        var _a;
        return (_a = this.formatterFn) !== null && _a !== void 0 ? _a : formatters[this.formatter];
    }
    // #endregion Public Accessors (2)
    // #region Private Accessors (1)
    get valueHolder() {
        return this.valueHolderRef.nativeElement;
    }
    // #endregion Private Accessors (1)
    // #region Public Methods (3)
    handleValueChange(valueChange) {
        this.valueHolder.style.transition = '';
        if (valueChange.currentValue > valueChange.previousValue) {
            this.valueHolder.classList.add(`${this.stylePrefix}--flashing-up`);
            this.valueHolder.style.backgroundColor = this.upColor;
        }
        else if (valueChange.currentValue < valueChange.previousValue) {
            this.valueHolder.classList.add(`${this.stylePrefix}--flashing-down`);
            this.valueHolder.style.backgroundColor = this.downColor;
        }
        clearTimeout(this.animationTimeout);
        this.animationTimeout = setTimeout(() => this.clearFlashingState(), this.timeout);
    }
    ngOnChanges(changes) {
        if (changes.value && changes.value.previousValue !== undefined) {
            this.handleValueChange(changes.value);
        }
    }
    // #endregion Public Methods (3)
    // #region Private Methods (1)
    clearFlashingState() {
        var _a;
        this.valueHolder.style.transition = (_a = this.transition) !== null && _a !== void 0 ? _a : `background-color ${this.transitionLength}ms ease-in-out`;
        this.valueHolder.classList.remove(`${this.stylePrefix}--flashing-down`);
        this.valueHolder.classList.remove(`${this.stylePrefix}--flashing-up`);
        this.valueHolder.style.backgroundColor = '';
    }
}
ValueFlashComponent.decorators = [
    { type: Component, args: [{
                selector: 'value-flash',
                template: "<div #valueHolder>{{ formattedValue }}</div>\r\n",
                changeDetection: ChangeDetectionStrategy.OnPush
            },] }
];
ValueFlashComponent.ctorParameters = () => [];
ValueFlashComponent.propDecorators = {
    downColor: [{ type: Input }],
    formatter: [{ type: Input }],
    formatterFn: [{ type: Input }],
    stylePrefix: [{ type: Input }],
    timeout: [{ type: Input }],
    transition: [{ type: Input }],
    transitionLength: [{ type: Input }],
    upColor: [{ type: Input }],
    value: [{ type: Input }],
    valueHolderRef: [{ type: ViewChild, args: ['valueHolder',] }]
};

class ValueFlashModule {
}
ValueFlashModule.decorators = [
    { type: NgModule, args: [{
                declarations: [ValueFlashComponent],
                imports: [],
                exports: [ValueFlashComponent],
            },] }
];

/*
 * Public API Surface of value-flash
 */

/**
 * Generated bundle index. Do not edit.
 */

export { ValueFlashComponent, ValueFlashModule };
//# sourceMappingURL=angular-value-flash.js.map
